c ######################################################################
c #
c #                 GLASS_EPOXY PROPERTIES PACKAGE
c #                 ------------------------------
c # Contains functions for the calculation of the thermo-physical
c # properties of glass-fiber/epoxy-resin impregnated composite
c #
c ######################################################################

c ######################################################################
      real function dGENormal(T)
c ######################################################################
c #
c # Density of glass/epoxy (G10)
c #
c # Range: 0 <= T <= inf K
c #
c #                        References
c #                        ----------
c # http://en.wikipedia.org/wiki/FR-4
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   dGE               x    density                           Kg/m**3
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 1.0   October 2012
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      

c * local variables

c *      
      dGENormal = 1850.0
c *

      return
      end
c ######################################################################
      real function cGENormal(T)
c ######################################################################
c #
c # Specific heat of glass-epoxy (G10)
c #
c # Range: 2 <= T <= 300 K
c #
c #                        References
c #                        ----------
c #
c # NIST Cryogenic Material Properties Database at:
c # http://cryogenics.nist.gov/MPropsMAY/material%20properties.htm
c # referring to: 
c # (1) Thermal Properties Database for Materials at Cryogenic  
c #     Temperatures. Ed. Holly M. Veres. P. 4.503
c # complemented with data from J. Schultz, private communication, August 
c # 2008, referring to: 
c # (2) Handbook on Materials for Superconducting Machinery, NBS Boulder
c #    (Yellow Book), 1977
c # complemented with data from:
c # (3) E.W. Collings, R.D. Smith, Adv. Cryo. Eng., 24, p290, 1978, Plenum 
c #     Press
c # complemented with data from:
c # (4) M. Shimada, Private Communication 1996
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   cGE               x    specific heat                     J/Kg K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 5.0   January 2021
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      
      real     AA,BB,a,b,na,nb
      real     Tmin,Tmax
c *
      data     AA  /   0.019201708 / ,  BB  / 1.275609E-03 /
      data     a   / 247.2061715   / ,  b   / 3.39266305   /
      data     na  /   2.199915285 /,   nb  / 9.273872746  /
c *
      data     Tmin / 2.0/, Tmax / 300.0/
      save    
c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

      cGENormal = AA*TT**na/(1+TT/a)**na + BB*TT**nb/(1+TT/b)**nb 

c *
      return
      end
c ######################################################################
      real function kGENormal(T)
c ######################################################################
c #
c # Thermal conductivity of glass-epoxy (G10) in the direction normal to
c # the fibers
c #
c # Range: 2 <= T <= 300 K
c #
c #                        References
c #                        ----------
c #
c # NIST Cryogenic Material Properties Database at:
c # http://cryogenics.nist.gov/MPropsMAY/material%20properties.htm
c # referring to: 
c # (1) Thermal Properties Database for Materials at Cryogenic  
c #     Temperatures. Ed. Holly M. Veres. P. 4.503
c # (2) Thermal Conductivity Of Glass Fiber/Epoxy Composite Support Bands 
c #     For Cryogenic Dewars, J.C. Hust.  Phase II NBS, Boulder, 1984. 
c # (3) Thermal Conductivity of Solids at Room Temperature and Below, 
c #     G. Child, L.J. Erics, R.L. Powell.  NBS Monograph 131 (1973).
c # complemented with data from J. Schultz, private communication, August 
c # 2008, referring to: 
c # (4) Handbook on Materials for Superconducting Machinery, NBS Boulder
c #    (Yellow Book), 1977
c # (5) M.B. Kasen, et al., "Mechanical, Electrical, and Thermal 
c #     Charaterization of Glass-Cloth/Epoxy Laminates", Adv. Cryo. Eng. 
c #     Materials, 26, Plenum Press, London
c #
c # variable          I/O    meaning                           units
c # --------------------------------------------------------------------
c #   T               x      absolute temperature              K
c #   kGENormal         x    thermal conductivity              W/m K
c #
c #
c # Author : L.Bottura at Cryosoft
c # Version: 5.0   January 2021
c #
c ######################################################################
      implicit none
c * external variables
      real     T
c * fit variables      
      real     AA,BB,a,b,na,nb
      real     Tmin,Tmax
      data     AA  /  0.003769081 / ,  BB  /  0.090847364 /
      data     a   /  11.15646872 / ,  b   /  1.546295081 / 
      data     na  /  0.187603238 / ,  nb  /  1.869793604 /
      data     Tmin / 2.0/, Tmax / 300.0/
c *     
      data     Tmin / 2.0/, Tmax / 300.0/
      save 

c * local variables
      real     TT
c *
      TT=T
      TT=min(TT,Tmax)
      TT=max(TT,Tmin)

c *      
       kGENormal = AA*TT   /(a+TT)**na + BB*TT**2/(b+TT)**nb

c *
      return
      end

